src/hotspot/share/memory/iterator.hpp
changeset 50870 830b05ca7f58
parent 50801 94b56c8594ef
child 52141 de6dc206a92b
--- a/src/hotspot/share/memory/iterator.hpp	Thu Jun 28 01:10:09 2018 -0700
+++ b/src/hotspot/share/memory/iterator.hpp	Wed Jun 27 15:02:53 2018 +0200
@@ -77,7 +77,8 @@
   enum ReferenceIterationMode {
     DO_DISCOVERY,                // Apply closure and discover references
     DO_DISCOVERED_AND_DISCOVERY, // Apply closure to discovered field and do discovery
-    DO_FIELDS                    // Apply closure to all fields
+    DO_FIELDS,                   // Apply closure to all fields
+    DO_FIELDS_EXCEPT_REFERENT    // Apply closure to all fields except the referent field
   };
 
   // The default iteration mode is to do discovery.